# DBA Tools

**Dependencies**

Assumes Teradata >=17.20.


**DBA** tools:

- dba_userSqlList - returns a list of recently executed SQL for a user
- dba_tableSqlList - returns a list of recently executed SQL for a table
- dba_tableSpace - returns CurrentPerm table space 
- dba_databaseSpace - returns Space allocated, space used and percentage used for a database
- dba_databaseVersion - returns the database version information
- dba_resusageSummary - Get the Teradata system usage summary metrics by weekday and hour for each workload type and query complexity bucket.
- dba_flowControl - Get the Teradata system flow control metrics by day and hour
- dba_featureUsage - Get the user feature usage metrics
- dba_userDelay - Get the Teradata user delay metrics.
- dba_tableUsageImpact - measures the usage of a table / view by a user
- dba_sessionInfo - gets session information for a user

**DBA** prompts:

- dba_databaseHealthAssessment - Create a database health assessment for a Teradata system
- dba_userActivityAnalysis - Create a user activity analysis for a Teradata system
- dba_tableArchive - Create a table archive strategy for database tables.
- dba_databaseLineage - Creates a directed lineage map of tables in a database.
- dba_tableDropImpact - assesses the impact of a table being dropped

[Return to Main README](../../../../README.md)
